labeltools.remove_markup_from_leaves_in_expr
============================================

.. autofunction:: abjad.tools.labeltools.remove_markup_from_leaves_in_expr.remove_markup_from_leaves_in_expr
